@@ -5,10 +5,16 @@ use 5.018;
 use strict;
 use warnings;
 
+# IMPORTS
+
 use Venus::Class 'attr', 'base', 'with';
 
+# INHERITS
+
 base 'Venus::Kind::Utility';
 
+# INTEGRATES
+
 with 'Venus::Role::Valuable';
 with 'Venus::Role::Buildable';
 with 'Venus::Role::Accessible';
@@ -41,18 +47,6 @@ sub build_self {
 
 # METHODS
 
-sub assertion {
-  my ($self) = @_;
-
-  my $assertion = $self->SUPER::assertion;
-
-  $assertion->match('arrayref')->format(sub{
-    (ref $self || $self)->new($_)
-  });
-
-  return $assertion;
-}
-
 sub default {
   my ($self) = @_;
 
@@ -376,6 +370,46 @@ I<Since C<0.01>>
 
 =cut
 
+=head2 new
+
+  new(any @args) (Venus::Args)
+
+The new method constructs an instance of the package.
+
+I<Since C<4.15>>
+
+=over 4
+
+=item new example 1
+
+  package main;
+
+  use Venus::Args;
+
+  my $new = Venus::Args->new;
+
+  # bless(..., "Venus::Args")
+
+=back
+
+=over 4
+
+=item new example 2
+
+  package main;
+
+  use Venus::Args;
+
+  my $new = Venus::Args->new(
+    value => ['--help', 'execute'],
+  );
+
+  # bless(..., "Venus::Args")
+
+=back
+
+=cut
+
 =head2 set
 
   set(string $key, any $data) (any)
