@@ -5,10 +5,16 @@ use 5.018;
 use strict;
 use warnings;
 
+# IMPORTS
+
 use Venus::Class 'base';
 
+# INHERITS
+
 base 'Venus::Kind::Value';
 
+# OVERLOADS
+
 use overload (
   '&{}' => sub{$_[0]->value},
   fallback => 1,
@@ -16,16 +22,6 @@ use overload (
 
 # METHODS
 
-sub assertion {
-  my ($self) = @_;
-
-  my $assert = $self->SUPER::assertion;
-
-  $assert->clear->expression('coderef');
-
-  return $assert;
-}
-
 sub call {
   my ($self, @args) = @_;
 
@@ -1890,6 +1886,58 @@ I<Since C<0.08>>
 
 =cut
 
+=head2 new
+
+  new(any @args) (Venus::Code)
+
+The new method constructs an instance of the package.
+
+I<Since C<4.15>>
+
+=over 4
+
+=item new example 1
+
+  package main;
+
+  use Venus::Code;
+
+  my $new = Venus::Code->new;
+
+  # bless(..., "Venus::Code")
+
+=back
+
+=over 4
+
+=item new example 2
+
+  package main;
+
+  use Venus::Code;
+
+  my $new = Venus::Code->new(sub{});
+
+  # bless(..., "Venus::Code")
+
+=back
+
+=over 4
+
+=item new example 3
+
+  package main;
+
+  use Venus::Code;
+
+  my $new = Venus::Code->new(value => sub{});
+
+  # bless(..., "Venus::Code")
+
+=back
+
+=cut
+
 =head2 next
 
   next(any @data) (any)
