@@ -5,15 +5,23 @@ use 5.018;
 use strict;
 use warnings;
 
+# IMPORTS
+
 use Venus::Class 'base', 'with';
 
+# INHERITS
+
 base 'Venus::Kind::Utility';
 
+# INTEGRATES
+
 with 'Venus::Role::Valuable';
 with 'Venus::Role::Buildable';
 with 'Venus::Role::Accessible';
 with 'Venus::Role::Explainable';
 
+# OVERLOADS
+
 use overload (
   '""' => 'explain',
   'eq' => sub{$_[0]->value eq "$_[1]"},
@@ -37,16 +45,6 @@ sub build_arg {
 
 # METHODS
 
-sub assertion {
-  my ($self) = @_;
-
-  my $assert = $self->SUPER::assertion;
-
-  $assert->clear->expression('string');
-
-  return $assert;
-}
-
 sub default {
   return 'Venus';
 }
@@ -471,6 +469,58 @@ I<Since C<0.01>>
 
 =cut
 
+=head2 new
+
+  new(any @args) (Venus::Name)
+
+The new method constructs an instance of the package.
+
+I<Since C<4.15>>
+
+=over 4
+
+=item new example 1
+
+  package main;
+
+  use Venus::Name;
+
+  my $new = Venus::Name->new;
+
+  # bless(..., "Venus::Name")
+
+=back
+
+=over 4
+
+=item new example 2
+
+  package main;
+
+  use Venus::Name;
+
+  my $new = Venus::Name->new('Foo/Bar');
+
+  # bless(..., "Venus::Name")
+
+=back
+
+=over 4
+
+=item new example 3
+
+  package main;
+
+  use Venus::Name;
+
+  my $new = Venus::Name->new(value => 'Foo/Bar');
+
+  # bless(..., "Venus::Name")
+
+=back
+
+=cut
+
 =head2 package
 
   package() (string)
