@@ -5,10 +5,16 @@ use 5.018;
 use strict;
 use warnings;
 
+# IMPORTS
+
 use Venus::Class 'base';
 
+# INHERITS
+
 base 'Venus::Kind::Value';
 
+# OVERLOADS
+
 use overload (
   '${}' => sub{$_[0]->value},
   '*{}' => sub{$_[0]->value},
@@ -17,18 +23,6 @@ use overload (
 
 # METHODS
 
-sub assertion {
-  my ($self) = @_;
-
-  my $assertion = $self->SUPER::assertion;
-
-  $assertion->match('scalarref')->format(sub{
-    (ref $self || $self)->new($_)
-  });
-
-  return $assertion;
-}
-
 sub default {
   return \'';
 }
@@ -1647,6 +1641,30 @@ I<Since C<0.08>>
 
 =cut
 
+=head2 new
+
+  new(any @args) (Venus::Scalar)
+
+The new method constructs an instance of the package.
+
+I<Since C<4.15>>
+
+=over 4
+
+=item new example 1
+
+  package main;
+
+  use Venus::Scalar;
+
+  my $new = Venus::Scalar->new;
+
+  # bless(..., "Venus::Scalar")
+
+=back
+
+=cut
+
 =head2 tv
 
   tv(any $arg) (boolean)
