@@ -5,8 +5,12 @@ use 5.018;
 use strict;
 use warnings;
 
+# IMPORTS
+
 use Venus::Class 'with';
 
+# INTEGRATES
+
 with 'Venus::Role::Buildable';
 with 'Venus::Role::Proxyable';
 with 'Venus::Role::Tryable';
@@ -211,6 +215,58 @@ I<Since C<3.55>>
 
 =cut
 
+=head2 new
+
+  new(any @args) (Venus::Sealed)
+
+The new method constructs an instance of the package.
+
+I<Since C<4.15>>
+
+=over 4
+
+=item new example 1
+
+  package main;
+
+  use Venus::Sealed;
+
+  my $new = Venus::Sealed->new;
+
+  # bless(..., "Venus::Sealed")
+
+=back
+
+=over 4
+
+=item new example 2
+
+  package main;
+
+  use Venus::Sealed;
+
+  my $new = Venus::Sealed->new('012345');
+
+  # bless(..., "Venus::Sealed")
+
+=back
+
+=over 4
+
+=item new example 3
+
+  package main;
+
+  use Venus::Sealed;
+
+  my $new = Venus::Sealed->new(value => '012345');
+
+  # bless(..., "Venus::Sealed")
+
+=back
+
+=cut
+
 =head2 set
 
   set(any @args) (any)
