@@ -5,12 +5,20 @@ use 5.018;
 use strict;
 use warnings;
 
+# IMPORTS
+
 use Venus::Class 'attr', 'base', 'with';
 
+# INHERITS
+
 base 'Venus::Kind::Utility';
 
+# INTEGRATES
+
+with 'Venus::Role::Encaseable';
 with 'Venus::Role::Explainable';
-with 'Venus::Role::Stashable';
+
+# OVERLOADS
 
 use overload (
   '""' => 'explain',
@@ -44,7 +52,7 @@ sub build_self {
 sub captures {
   my ($self) = @_;
 
-  my $evaluation = $self->stash('evaluation') || $self->evaluate;
+  my $evaluation = $self->encased('evaluation') || $self->evaluate;
 
   my $string = $self->initial;
   my $last_match_start = $self->last_match_start;
@@ -81,10 +89,10 @@ sub evaluate {
   my $error = $@;
 
   if ($error) {
-    $self->error({throw => 'error_on_evaluate', error => $error});
+    $self->error_on_evaluate({error => $error})->throw;
   }
 
-  return $self->stash(evaluation => [
+  return $self->recase(evaluation => [
     $regexp,
     $string,
     $captures,
@@ -102,7 +110,7 @@ sub explain {
 sub get {
   my ($self) = @_;
 
-  my $evaluation = $self->stash('evaluation') || $self->evaluate;
+  my $evaluation = $self->encased('evaluation') || $self->evaluate;
 
   return $evaluation->[1];
 }
@@ -110,7 +118,7 @@ sub get {
 sub count {
   my ($self) = @_;
 
-  my $evaluation = $self->stash('evaluation') || $self->evaluate;
+  my $evaluation = $self->encased('evaluation') || $self->evaluate;
 
   return $evaluation->[2];
 }
@@ -118,7 +126,7 @@ sub count {
 sub initial {
   my ($self) = @_;
 
-  my $evaluation = $self->stash('evaluation') || $self->evaluate;
+  my $evaluation = $self->encased('evaluation') || $self->evaluate;
 
   return $evaluation->[6];
 }
@@ -126,7 +134,7 @@ sub initial {
 sub last_match_end {
   my ($self) = @_;
 
-  my $evaluation = $self->stash('evaluation') || $self->evaluate;
+  my $evaluation = $self->encased('evaluation') || $self->evaluate;
 
   return $evaluation->[4];
 }
@@ -134,7 +142,7 @@ sub last_match_end {
 sub last_match_start {
   my ($self) = @_;
 
-  my $evaluation = $self->stash('evaluation') || $self->evaluate;
+  my $evaluation = $self->encased('evaluation') || $self->evaluate;
 
   return $evaluation->[3];
 }
@@ -142,7 +150,7 @@ sub last_match_start {
 sub matched {
   my ($self) = @_;
 
-  my $evaluation = $self->stash('evaluation') || $self->evaluate;
+  my $evaluation = $self->encased('evaluation') || $self->evaluate;
 
   my $string = $self->initial;
   my $last_match_start = $self->last_match_start;
@@ -157,7 +165,7 @@ sub matched {
 sub named_captures {
   my ($self) = @_;
 
-  my $evaluation = $self->stash('evaluation') || $self->evaluate;
+  my $evaluation = $self->encased('evaluation') || $self->evaluate;
 
   return $evaluation->[5];
 }
@@ -165,7 +173,7 @@ sub named_captures {
 sub prematched {
   my ($self) = @_;
 
-  my $evaluation = $self->stash('evaluation') || $self->evaluate;
+  my $evaluation = $self->encased('evaluation') || $self->evaluate;
 
   my $string = $self->initial;
   my $last_match_start = $self->last_match_start;
@@ -180,7 +188,7 @@ sub prematched {
 sub postmatched {
   my ($self) = @_;
 
-  my $evaluation = $self->stash('evaluation') || $self->evaluate;
+  my $evaluation = $self->encased('evaluation') || $self->evaluate;
 
   my $string = $self->initial;
   my $last_match_start = $self->last_match_start;
@@ -207,13 +215,15 @@ sub set {
 sub error_on_evaluate {
   my ($self, $data) = @_;
 
-  my $result = {
-    name => 'on.evaluate',
-    raise => true,
-    message => $data->{error},
-  };
+  my $error = $self->error->sysinfo;
 
-  return $result;
+  $error->name('on.evaluate');
+  $error->message($data->{error});
+  $error->offset(1);
+  $error->stash($data);
+  $error->reset;
+
+  return $error;
 }
 
 1;
@@ -295,9 +305,9 @@ L<Venus::Kind::Utility>
 
 This package integrates behaviors from:
 
-L<Venus::Role::Explainable>
+L<Venus::Role::Encaseable>
 
-L<Venus::Role::Stashable>
+L<Venus::Role::Explainable>
 
 =cut
 
@@ -394,6 +404,30 @@ I<Since C<0.01>>
 
 =back
 
+=over 4
+
+=item B<may raise> L<Venus::Search::Error> C<on.evaluate>
+
+  package main;
+
+  use Venus::Search;
+
+  my $search = Venus::Search->new(
+    string => 'hello world',
+    regexp => 'world',
+    flags => 'i',
+  );
+
+  $search->evaluate;
+
+  $search->flags('q');
+
+  $search->evaluate;
+
+  # Error! (on.evaluate)
+
+=back
+
 =cut
 
 =head2 explain
@@ -579,6 +613,47 @@ I<Since C<0.01>>
 
 =cut
 
+=head2 new
+
+  new(any @args) (Venus::Search)
+
+The new method constructs an instance of the package.
+
+I<Since C<4.15>>
+
+=over 4
+
+=item new example 1
+
+  package main;
+
+  use Venus::Search;
+
+  my $new = Venus::Search->new;
+
+  # bless(..., "Venus::Search")
+
+=back
+
+=over 4
+
+=item new example 2
+
+  package main;
+
+  use Venus::Search;
+
+  my $new = Venus::Search->new(
+    string => 'hello world',
+    regexp => '(hello)',
+  );
+
+  # bless(..., "Venus::Search")
+
+=back
+
+=cut
+
 =head2 postmatched
 
   postmatched() (maybe[string])
@@ -649,39 +724,6 @@ I<Since C<0.01>>
 
 =cut
 
-=head1 ERRORS
-
-This package may raise the following errors:
-
-=cut
-
-=over 4
-
-=item error: C<error_on_evaluate>
-
-This package may raise an error_on_evaluate exception.
-
-B<example 1>
-
-  # given: synopsis;
-
-  my $input = {
-    throw => 'error_on_evaluate',
-    error => 'Exception!',
-  };
-
-  my $error = $search->catch('error', $input);
-
-  # my $name = $error->name;
-
-  # "on_evaluate"
-
-  # my $message = $error->message;
-
-  # "Exception!"
-
-=back
-
 =head1 OPERATORS
 
 This package overloads the following operators:
