@@ -5,8 +5,12 @@ use 5.018;
 use strict;
 use warnings;
 
+# IMPORTS
+
 use Venus::Class 'base';
 
+# INHERITS
+
 base 'Venus::Kind::Value';
 
 no overloading;
@@ -23,18 +27,6 @@ sub build_self {
 
 # METHODS
 
-sub assertion {
-  my ($self) = @_;
-
-  my $assertion = $self->SUPER::assertion;
-
-  $assertion->match('undef')->format(sub{
-    (ref $self || $self)->new
-  });
-
-  return $assertion;
-}
-
 sub comparer {
   my ($self) = @_;
 
@@ -1672,6 +1664,30 @@ I<Since C<0.08>>
 
 =cut
 
+=head2 new
+
+  new(any @args) (Venus::Undef)
+
+The new method constructs an instance of the package.
+
+I<Since C<4.15>>
+
+=over 4
+
+=item new example 1
+
+  package main;
+
+  use Venus::Undef;
+
+  my $new = Venus::Undef->new;
+
+  # bless(..., "Venus::Undef")
+
+=back
+
+=cut
+
 =head2 numified
 
   numified() (number)
